@@ -12,7 +12,14 @@ from .callbacks import _DEFAULT_CALLBACK
 from .config import apply_config, conf
 from .dircache import DirCache
 from .transaction import Transaction
-from .utils import _unstrip_protocol, other_paths, read_block, stringify_path, tokenize
+from .utils import (
+    _unstrip_protocol,
+    isfilelike,
+    other_paths,
+    read_block,
+    stringify_path,
+    tokenize,
+)
 
 logger = logging.getLogger("fsspec")
 
@@ -63,6 +70,7 @@ class _Cached(type):
             cls._cache.clear()
             cls._pid = os.getpid()
         if not skip and cls.cachable and token in cls._cache:
+            cls._latest = token
             return cls._cache[token]
         else:
             obj = super().__call__(*args, **kwargs)
@@ -76,6 +84,7 @@ class _Cached(type):
                 mirror_sync_methods(obj)
 
             if cls.cachable and not skip:
+                cls._latest = token
                 cls._cache[token] = obj
             return obj
 
@@ -90,9 +99,10 @@ class AbstractFileSystem(metaclass=_Cached):
 
     cachable = True  # this class can be cached, instances reused
     _cached = False
-    blocksize = 2 ** 22
+    blocksize = 2**22
     sep = "/"
     protocol = "abstract"
+    _latest = None
     async_impl = False
     root_marker = ""  # For some FSs, may require leading '/' or other character
 
@@ -175,6 +185,14 @@ class AbstractFileSystem(metaclass=_Cached):
         # use of root_marker to make minimum required path, e.g., "/"
         return path or cls.root_marker
 
+    def unstrip_protocol(self, name):
+        """Format FS-specific path to generic, including protocol"""
+        protos = (self.protocol,) if isinstance(self.protocol, str) else self.protocol
+        for protocol in protos:
+            if name.startswith(f"{protocol}://"):
+                return name
+        return f"{protos[0]}://{name}"
+
     @staticmethod
     def _get_kwargs_from_urls(path):
         """If kwargs can be encoded in the paths, extract them here
@@ -190,14 +208,13 @@ class AbstractFileSystem(metaclass=_Cached):
 
     @classmethod
     def current(cls):
-        """Return the most recently created FileSystem
+        """Return the most recently instantiated FileSystem
 
         If no instance has been created, then create one with defaults
         """
-        if not len(cls._cache):
-            return cls()
-        else:
-            return list(cls._cache.values())[-1]
+        if cls._latest in cls._cache:
+            return cls._cache[cls._latest]
+        return cls()
 
     @property
     def transaction(self):
@@ -403,7 +420,7 @@ class AbstractFileSystem(metaclass=_Cached):
         for d in full_dirs:
             yield from self.walk(d, maxdepth=maxdepth, detail=detail, **kwargs)
 
-    def find(self, path, maxdepth=None, withdirs=False, **kwargs):
+    def find(self, path, maxdepth=None, withdirs=False, detail=False, **kwargs):
         """List all files below path.
 
         Like posix ``find`` command without conditions
@@ -421,7 +438,6 @@ class AbstractFileSystem(metaclass=_Cached):
         # TODO: allow equivalent of -name parameter
         path = self._strip_protocol(path)
         out = dict()
-        detail = kwargs.pop("detail", False)
         for _, dirs, files in self.walk(path, maxdepth, detail=True, **kwargs):
             if withdirs:
                 files.update(dirs)
@@ -660,7 +676,7 @@ class AbstractFileSystem(metaclass=_Cached):
 
     def pipe_file(self, path, value, **kwargs):
         """Set the bytes of given file"""
-        with self.open(path, "wb") as f:
+        with self.open(path, "wb", **kwargs) as f:
             f.write(value)
 
     def pipe(self, path, value=None, **kwargs):
@@ -738,20 +754,29 @@ class AbstractFileSystem(metaclass=_Cached):
         else:
             return self.cat_file(paths[0], **kwargs)
 
-    def get_file(self, rpath, lpath, callback=_DEFAULT_CALLBACK, **kwargs):
+    def get_file(
+        self, rpath, lpath, callback=_DEFAULT_CALLBACK, outfile=None, **kwargs
+    ):
         """Copy single remote file to local"""
-        if self.isdir(rpath):
-            os.makedirs(lpath, exist_ok=True)
-            return None
+        if isfilelike(lpath):
+            outfile = lpath
+        else:
+            if self.isdir(rpath):
+                os.makedirs(lpath, exist_ok=True)
+                return None
+
+            if outfile is None:
+                outfile = open(lpath, "wb")
 
         with self.open(rpath, "rb", **kwargs) as f1:
             callback.set_size(getattr(f1, "size", None))
-            with open(lpath, "wb") as f2:
-                data = True
-                while data:
-                    data = f1.read(self.blocksize)
-                    segment_len = f2.write(data)
-                    callback.relative_update(segment_len)
+            data = True
+            while data:
+                data = f1.read(self.blocksize)
+                segment_len = outfile.write(data)
+                callback.relative_update(segment_len)
+        if not isfilelike(lpath):
+            outfile.close()
 
     def get(self, rpath, lpath, recursive=False, callback=_DEFAULT_CALLBACK, **kwargs):
         """Copy file(s) to local.
@@ -1153,7 +1178,7 @@ class AbstractFileSystem(metaclass=_Cached):
         # all instances already also derive from pyarrow
         return self
 
-    def get_mapper(self, root="", check=False, create=False):
+    def get_mapper(self, root="", check=False, create=False, missing_exceptions=None):
         """Create key/value store based on this file-system
 
         Makes a MutableMapping interface to the FS at the given root path.
@@ -1161,7 +1186,13 @@ class AbstractFileSystem(metaclass=_Cached):
         """
         from .mapping import FSMap
 
-        return FSMap(root, self, check, create)
+        return FSMap(
+            root,
+            self,
+            check=check,
+            create=create,
+            missing_exceptions=missing_exceptions,
+        )
 
     @classmethod
     def clear_instance_cache(cls):
@@ -1274,7 +1305,7 @@ class AbstractBufferedFile(io.IOBase):
     ``_initiate_upload`` and ``_fetch_range``.
     """
 
-    DEFAULT_BLOCK_SIZE = 5 * 2 ** 20
+    DEFAULT_BLOCK_SIZE = 5 * 2**20
     _details = None
 
     def __init__(
